import pandas as pd
import scipy.stats as stats

α = 0.05


def ReadData(dataset):
    dataset = pd.read_csv(dataset)
    return dataset


class Male:
    def __init__(self, dataset):
        self.dataset = dataset.loc[dataset['sex'] == 'Male']

    def Mean_bp(self):
        return self.dataset[['bp_before', 'bp_after']].mean()

    def T_test(self):
        return stats.ttest_rel(self.dataset['bp_before'], self.dataset['bp_after'])

    def Conclusion_Hypothesis(self):
        reject = ['Reject Null Hypothesis ❌',
                  'The drug is effective for male patient 😁']
        accept = ['Accept Null Hypothesis ✅',
                  'The drug is not effective for male patient ☹️']
        if self.T_test()[1] < α:
            return reject
        else:
            return accept


class Female:
    def __init__(self, dataset):
        self.dataset = dataset.loc[dataset['sex'] == 'Female']

    def Mean_bp(self):
        return self.dataset[['bp_before', 'bp_after']].mean()

    def T_test(self):
        return stats.ttest_rel(self.dataset['bp_before'], self.dataset['bp_after'])

    def Conclusion_Hypothesis(self):
        reject = ['Reject Null Hypothesis ❌',
                  'The drug is effective for female patient 😁']
        accept = ['Accept Null Hypothesis ✅',
                  'The drug is not effective for female patient ☹️']
        if self.T_test()[1] < α:
            return reject
        else:
            return accept



from setuptools import setup, find_packages
import codecs
import os

VERSION = '1.0.1'
DESCRIPTION = 'Calculates test drug patients good or not'
LONG_DESCRIPTION = 'A package that calculates test drug patients good or not'

# Setting up
setup(
    name="stats_drug_test_patients",
    version=VERSION,
    author="PunGrumpy",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    install_requires=[],
    keywords=['python', 'statistics', 'education'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Microsoft :: Windows",
    ]
)
